@@ -73,68 +73,80 @@ pasteXMLTag <- function(tag, attr=NULL, child=NULL, empty=TRUE, level=1, allow.e
   new.cmmt.indent <- ifelse(shine > 1, indent(level + 1, by=indent.by), "")
   comment.indent <- ifelse(shine > 0, indent(level + 1, by=indent.by), "")
 
-  # three special cases: value pseudotags, comments and CDATA
+  # test variuos special cases: value pseudotags, XML declarations, comments and CDATA
   if(isTRUE(nchar(tag) == 0) | length(tag) == 0){
     if(isTRUE(tidy)){
       child <- trim(child)
       child <- gsub("\n", new.cmmt, trim(setMinIndent(child, level=2, indent.by=indent.by)))
     }
     full.tag <- paste0(child, " ")
-  } else {
-    switch(tag,
-     "!--"={
-       # clean up value if needed
-       if(!is.null(child)){
-         if(isTRUE(tidy)){
-           child <- trim(child)
-           child <- gsub("\n", new.cmmt, trim(setMinIndent(child, level=level, indent.by=indent.by)))
-         }
-       } else {}
-       full.tag <- paste0(new.indent, "<!-- ", new.attr, new.cmmt.indent,
-         child, " ", new.attr, new.attr.indent,
-         "-->", new.node)
-       },
-     "![CDATA["={
-       # clean up value if needed
-       if(!is.null(child)){
-          child <- trim(child)
-          if(isTRUE(tidy)){
-            child <- gsub("\n", new.cmmt, trim(setMinIndent(child, level=level, indent.by=indent.by)))
-          }
-        } else {}
-        full.tag <- paste0(new.indent, "<![CDATA[ ", new.cmmt, comment.indent,
-          child, " ", new.cmmt, new.indent,
-          "]]>", new.node)},
-      "*![CDATA["={
-        # clean up value if needed
-        if(!is.null(child)){
-          child <- trim(child)
-          if(isTRUE(tidy)){
-            child <- gsub("\n", new.cmmt, trim(setMinIndent(child, level=level, indent.by=indent.by)))
-          }
-        } else {}
-        # 
-        full.tag <- paste0(new.indent, "/* <![CDATA[ */ ", new.cmmt, comment.indent,
-          child, " ", new.cmmt, new.indent,
-          "/* ]]> */", new.node)},
-      # last but not least, the default value
-      {
-        # only put attributes in new lines if there's more than one
-        new.attr <- ifelse((length(attr) > 1), new.attr, "")
-        new.attr.indent <- ifelse((length(attr) > 1), new.attr.indent, "")
-        new.cmmt.indent <- ifelse((length(attr) > 1), new.cmmt.indent, "")
-        val.indent <- ifelse(shine > 0, indent(level + 1, by=indent.by), "")
-        # empty decides whether this is a empty tag or a pair of start and end tags
-        if(isTRUE(empty)){
-          full.tag <- paste0(new.indent, "<", tag, attr.space, new.attr, new.cmmt.indent, all.attributes, new.attr, new.attr.indent, " />", new.node)
-        } else {
-          full.tag <- paste0(
-            new.indent, "<", tag, attr.space, new.attr, new.cmmt.indent, all.attributes, new.attr, new.attr.indent, ">", new.node,
-            if(!is.null(child)){paste0(val.indent, trim(child), new.node)},
-            new.indent, "</", tag, ">", new.node)
-        }
+  } else if(grepl("^\\?", tag)){
+    if(is.null(child)){
+      full.tag <- paste0(new.indent, "<", tag, attr.space, new.attr, new.cmmt.indent,
+        all.attributes, new.attr, new.attr.indent, " ?>", new.node
+      )
+    } else {
+      stop(simpleError("child nodes for XML declaraions are not supported!"))
+    }
+  } else if(identical(tag, "!--")){
+    # clean up value if needed
+    if(!is.null(child)){
+      if(isTRUE(tidy)){
+        child <- trim(child)
+        child <- gsub("\n", new.cmmt, trim(setMinIndent(child, level=level, indent.by=indent.by)))
       }
-    )
+    } else {}
+    full.tag <- paste0(new.indent, "<!-- ", new.attr, new.cmmt.indent,
+      child, " ", new.attr, new.attr.indent,
+      "-->", new.node)
+  } else if(identical(tag, "![CDATA[")){
+    # clean up value if needed
+    if(!is.null(child)){
+      child <- trim(child)
+      if(isTRUE(tidy)){
+        child <- gsub("\n", new.cmmt, trim(setMinIndent(child, level=level, indent.by=indent.by)))
+      }
+    } else {}
+    full.tag <- paste0(new.indent, "<![CDATA[ ", new.cmmt, comment.indent,
+      child, " ", new.cmmt, new.indent,
+      "]]>", new.node)
+  } else if(identical(tag, "*![CDATA[")){
+    # clean up value if needed
+    if(!is.null(child)){
+      child <- trim(child)
+      if(isTRUE(tidy)){
+        child <- gsub("\n", new.cmmt, trim(setMinIndent(child, level=level, indent.by=indent.by)))
+      }
+    } else {}
+    full.tag <- paste0(new.indent, "/* <![CDATA[ */ ", new.cmmt, comment.indent,
+      child, " ", new.cmmt, new.indent,
+      "/* ]]> */", new.node)
+  } else if(grepl("^!", tag)){
+    if(!is.null(child)){
+      child <- trim(child)
+      if(isTRUE(tidy)){
+        child <- gsub("\n", new.cmmt, trim(setMinIndent(child, level=level, indent.by=indent.by)))
+      }
+    } else {}
+    full.tag <- paste0(new.indent, "<", tag, new.attr, new.cmmt.indent,
+      child, " ", all.attributes, new.attr, new.attr.indent,
+      ">", new.node)
+  } else {
+    # last but not least, the default value
+    # only put attributes in new lines if there's more than one
+    new.attr <- ifelse((length(attr) > 1), new.attr, "")
+    new.attr.indent <- ifelse((length(attr) > 1), new.attr.indent, "")
+    new.cmmt.indent <- ifelse((length(attr) > 1), new.cmmt.indent, "")
+    val.indent <- ifelse(shine > 0, indent(level + 1, by=indent.by), "")
+    # empty decides whether this is a empty tag or a pair of start and end tags
+    if(isTRUE(empty)){
+      full.tag <- paste0(new.indent, "<", tag, attr.space, new.attr, new.cmmt.indent, all.attributes, new.attr, new.attr.indent, " />", new.node)
+    } else {
+      full.tag <- paste0(
+        new.indent, "<", tag, attr.space, new.attr, new.cmmt.indent, all.attributes, new.attr, new.attr.indent, ">", new.node,
+        if(!is.null(child)){paste0(val.indent, trim(child), new.node)},
+        new.indent, "</", tag, ">", new.node)
+    }
   }
   return(full.tag)
 }
